<template>
    <div class="system-add-menu-container">
        <el-dialog :title="title" v-model="isShowInspectPointDialog" width="600px">
            <el-form :model="inspectPointForm" :rules="inspectPointFormRules" ref="inspectPointFormRef" size="default" label-width="120px">
                <el-row :gutter="35">
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="巡检点名称" prop="code">
                            <el-input class="input-length" v-model.trim="inspectPointForm.code" placeholder="请输入巡检点名称" clearable></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="所属设备区域" prop="regionId">
                            <el-select class="input-length" v-model="inspectPointForm.regionId" placeholder="请选择所属设备区域" clearable filterable>
                                <el-option v-for="item in regionNameList" :key="item.id" :label="item.region" :value="item.id"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="关联RFID" prop="rfidId">
                            <el-select class="input-length" v-model="inspectPointForm.rfidId" placeholder="请选择关联RFID" clearable filterable>
                                <el-option v-for="item in RFIDList" :key="item.id" :label="item.rfidName" :value="item.id"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <template #footer>
                <span class="dialog-footer">
                    <el-button @click="isShowInspectPointDialog = !isShowInspectPointDialog" size="default">取 消</el-button>
                    <el-button type="primary" @click="submitInspectPoint" v-throttle size="default">确 定</el-button>
                </span>
            </template>
        </el-dialog>
    </div>
</template>

<script lang="ts">
import { facilityAreaApi } from '/@/api/intellectInspectSystem/facilityAreaManage';

interface stateType {
    isShowInspectPointDialog: Boolean;
    inspectPointForm: {
        code: string;
        regionId: number | null;
        rfidId: number | null;
    };
    title: string;
    regionNameList: [];
    RFIDList: Array<levelListState>;
    inspectPointFormRules: {};
}
interface levelListState {}
import { reactive, toRefs, ref } from 'vue';
import { inspectPointApi } from '/@/api/intellectInspectSystem/inspectPointManage';
import { ElMessage } from 'element-plus';
export default {
    name: 'inspectPointDialog',
    setup(props: any, context: any) {
        const inspectPointFormRef = ref();
        const state = reactive<stateType>({
            title: '',
            isShowInspectPointDialog: false,
            inspectPointForm: {
                code: '',
                regionId: null,
                rfidId: null
            },
            regionNameList: [],
            RFIDList: [],
            inspectPointFormRules: {
                code: [{ required: true, message: '请填写巡检点名称', trigger: 'blur' }],
                regionId: [{ required: true, message: '请选择所属设施区域', trigger: 'change' }],
                rfidId: [{ required: true, message: '请选择关联RFID', trigger: 'change' }]
            }
        });

        //打开模态框
        const openInspectPointDialog = (type: string, value: { id: number }, regionNameList: [], RFIDList: []) => {
            state.isShowInspectPointDialog = true;
            state.regionNameList = regionNameList;
            state.RFIDList = RFIDList;
            setTimeout(() => {
                inspectPointFormRef.value.clearValidate();
            });
            if (type === '新增') {
                state.title = '新增巡检点';
                state.inspectPointForm = {
                    code: '',
                    regionId: null,
                    rfidId: null
                };
            } else {
                state.title = '修改巡检点';
                inspectPointApi()
                    .getInspectPointById({ id: value.id })
                    .then((res) => {
                        if (res.data.code === '200') {
                            state.inspectPointForm = JSON.parse(JSON.stringify(res.data.data));
                        } else {
                        }
                    })
                    .catch((error) => {});
            }
        };

        //新增修改提交
        const submitInspectPoint = async () => {
            inspectPointFormRef.value.validate(async (valid: Boolean) => {
                if (valid) {
                    if (state.title === '新增巡检点') {
                        let res = await inspectPointApi().addInspectPoint(state.inspectPointForm);
                        if (res.data.code === '200') {
                            ElMessage({
                                type: 'success',
                                message: '巡检点新增成功',
                                duration: 2000
                            });
                            state.isShowInspectPointDialog = false;
                            context.emit('refreshInspectPoint');
                        } else {
                            ElMessage({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    } else {
                        let res = await inspectPointApi().modInspectPoint(state.inspectPointForm);
                        if (res.data.code === '200') {
                            ElMessage({
                                type: 'success',
                                message: '巡检点修改成功',
                                duration: 2000
                            });
                            state.isShowInspectPointDialog = false;
                            context.emit('refreshInspectPoint');
                        } else {
                            ElMessage({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    }
                } else {
                    ElMessage({
                        type: 'warning',
                        message: '请完善基本信息'
                    });
                }
            });
        };

        return {
            ...toRefs(state),
            inspectPointFormRef,
            submitInspectPoint,
            openInspectPointDialog
        };
    }
};
</script>

<style scoped>
.input-length {
    width: 85%;
}
</style>
